@@ -1,15 +1,20 @@
-from __future__ import absolute_import
-
+# -*- coding: utf-8 -*-
+##############################################
+# The MIT License (MIT)
+# Copyright (c) 2014 Kevin Walchko
+# see LICENSE for full details
+##############################################
 from squaternion.squaternion import Quaternion
 from squaternion.squaternion import euler2quat
 from squaternion.squaternion import quat2euler
 from squaternion.squaternion import quatNorm
 
-__author__ = "Kevin Walchko"
-__license__ = "MIT"
-# __version__ = "0.1.0"
 
 try:
     from importlib.metadata import version # type: ignore
 except ImportError:
     from importlib_metadata import version # type: ignore
+
+__author__ = "Kevin Walchko"
+__license__ = "MIT"
+__version__ = version("squaternion")
